@@ -2,16 +2,15 @@ use crate::error::LightSpeedError;
 use serde::{Deserialize, Serialize};
 use std::str::FromStr;
 use strum::{AsRefStr, Display, EnumIter};
-use typescript_definitions::TypeScriptify;
 
-#[derive(Clone, Debug, Display, EnumIter, AsRefStr, Serialize, Deserialize, PartialEq, Eq, Hash, TypeScriptify)]
-#[allow(non_camel_case_types)]
+#[derive(Clone, Debug, Display, EnumIter, AsRefStr, Serialize, Deserialize, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "poem_openapi_", derive(poem_openapi::Enum))]
 pub enum Language {
-    DE,
-    EN,
-    ES,
-    FR,
-    IT,
+    De,
+    En,
+    Es,
+    Fr,
+    It,
 }
 
 impl FromStr for Language {
@@ -19,11 +18,11 @@ impl FromStr for Language {
 
     fn from_str(language: &str) -> Result<Self, Self::Err> {
         match language.to_lowercase().as_ref() {
-            "de" => Ok(Language::DE),
-            "en" => Ok(Language::EN),
-            "es" => Ok(Language::ES),
-            "fr" => Ok(Language::FR),
-            "it" => Ok(Language::IT),
+            "de" => Ok(Language::De),
+            "en" => Ok(Language::En),
+            "es" => Ok(Language::Es),
+            "fr" => Ok(Language::Fr),
+            "it" => Ok(Language::It),
             _ => {
                 Err(LightSpeedError::ConfigurationError { message: format!("Could not parse language [{}]", language) })
             }
