@@ -1,12 +1,12 @@
 use crate::service::auth::Owned;
 use crate::service::validator::ownership::WithIdAndVersion;
 use serde::{Deserialize, Serialize};
-use typescript_definitions::TypeScriptify;
 
 pub mod language;
 pub mod model_dto;
 
-#[derive(Clone, Debug, PartialEq, Deserialize, Serialize, TypeScriptify)]
+#[derive(Clone, Debug, PartialEq, Deserialize, Serialize)]
+
 pub struct ModelWithOwner<D> {
     pub id: i64,
     pub version: i32,
